# md-anchors

![Tests](https://github.com/LeMinaw/md-anchors/actions/workflows/python-package.yml/badge.svg)
[![Codecov](https://codecov.io/gh/LeMinaw/md-anchors/branch/main/graph/badge.svg?token=FF9BKKCUVB)](https://codecov.io/gh/LeMinaw/md-anchors)

Tiny lib to work with Markdown / CommonMark anchors.
